@@ -10,37 +10,48 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.01';
-$DATE = '2003/07/08';
+$VERSION = '0.04';
+$DATE = '2003/08/04';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/ExtUtils_SVDmaker.pm' => [qw(0.01 2003/07/08), 'revised 0.01'],
-    'MANIFEST' => [qw(0.01 2003/07/08), 'generated, replaces 0.01'],
-    'Makefile.PL' => [qw(0.01 2003/07/08), 'generated, replaces 0.01'],
-    'README' => [qw(0.01 2003/07/08), 'generated, replaces 0.01'],
-    'lib/ExtUtils/SVDmaker.pm' => [qw(1.03 2003/07/08), 'revised 1.02'],
-    'bin/vmake.pl' => [qw(1.02 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/Makefile2.PL' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/Makefile3.PL' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/MANIFEST2' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/README2' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/README3' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/SVDmaker.d' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/SVDmaker.pm' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/SVDmaker.t' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/SVDmaker0.pm' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/SVDtest.ppd' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/SVDtest2.pm' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/SVDtest2.ppd' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/SVDtest3.pm' => [qw(0.02 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/SVDtest3.ppd' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/lib/module0.pm' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/lib/SVDtest0.pm' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/lib/SVDtest1.pm' => [qw(0.02 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/t/SVDtest0.t' => [qw(0.01 2003/07/08), 'new'],
-    't/ExtUtils/SVDmaker/t/SVDtest2.t' => [qw(0.06 2003/07/08), 'new'],
+    'lib/Docs/Site_SVD/ExtUtils_SVDmaker.pm' => [qw(0.04 2003/08/04), 'revised 0.03'],
+    'MANIFEST' => [qw(0.04 2003/08/04), 'generated, replaces 0.03'],
+    'Makefile.PL' => [qw(0.04 2003/08/04), 'generated, replaces 0.03'],
+    'README' => [qw(0.04 2003/08/04), 'generated, replaces 0.03'],
+    'lib/ExtUtils/SVDmaker.pm' => [qw(1.06 2003/08/04), 'revised 1.05'],
+    'bin/vmake.pl' => [qw(1.04 2003/08/04), 'revised 1.03'],
+    't/ExtUtils/SVDmaker/SVDmaker.d' => [qw(0.04 2003/08/04), 'revised 0.03'],
+    't/ExtUtils/SVDmaker/SVDmaker.pm' => [qw(0.04 2003/08/04), 'revised 0.03'],
+    't/ExtUtils/SVDmaker/SVDmaker.t' => [qw(0.04 2003/08/04), 'revised 0.03'],
+    't/ExtUtils/SVDmaker/lib/SVDtest1.pm' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/lib/SVDtest1.t' => [qw(0.02 2003/08/04), 'new'],
+    'tlib/Test/Tech.pm' => [qw(1.12 2003/08/04), 'unchanged'],
+    'tlib/File/SmartNL.pm,' => [qw(1.12 2003/08/04), 'revised 1.11'],
+    't/ExtUtils/SVDmaker/expected/Makefile' => [qw(0.04 2003/08/04), 'new'],
+    't/ExtUtils/SVDmaker/expected/Makefile2.PL' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/Makefile3.PL' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/MANIFEST2' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/module0A.pm' => [qw(0.04 2003/08/04), 'new'],
+    't/ExtUtils/SVDmaker/expected/module0B.pm' => [qw(0.04 2003/08/04), 'new'],
+    't/ExtUtils/SVDmaker/expected/module2.pm' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/README2' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/README3' => [qw(0.04 2003/08/04), 'revised 0.03'],
+    't/ExtUtils/SVDmaker/expected/SVDmaker0.pm' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/SVDtest-0.01.html' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/SVDtest.ppd' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/SVDtest0A.pm' => [qw(0.04 2003/08/04), 'new'],
+    't/ExtUtils/SVDmaker/expected/SVDtest0A.t' => [qw(0.04 2003/08/04), 'new'],
+    't/ExtUtils/SVDmaker/expected/SVDtest0B.pm' => [qw(0.04 2003/08/04), 'new'],
+    't/ExtUtils/SVDmaker/expected/SVDtest0B.t' => [qw(0.04 2003/08/04), 'new'],
+    't/ExtUtils/SVDmaker/expected/SVDtest2-0.01.html' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/SVDtest2.pm' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/SVDtest2.ppd' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/SVDtest2.t' => [qw(0.04 2003/08/04), 'new'],
+    't/ExtUtils/SVDmaker/expected/SVDtest3-0.02.html' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/expected/SVDtest3.pm' => [qw(0.04 2003/08/04), 'revised 0.03'],
+    't/ExtUtils/SVDmaker/expected/SVDtest3.ppd' => [qw(0.03 2003/08/04), 'revised 0.02'],
 
 );
 
@@ -67,11 +78,11 @@ use vars qw(%INVENTORY);
 
  ExtUtil::SVDmaker - Packaging modules for CPAN and Software Version Description (SVD) Automation
 
- Revision: -
+ Revision: C
 
- Version: 0.01
+ Version: 0.04
 
- Date: 2003/07/08
+ Date: 2003/08/04
 
  Prepared for: General Public 
 
@@ -100,57 +111,49 @@ As established by the L<Perl referenced documents|/2.0 SEE ALSO>,
 the "L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>" 
 program module extends the Perl language.
 
-
-The input to "L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>" is the __DATA__
-section of Software Test Description (STD)
-program module.
-The __DATA__ section must contain STD
-forms text database in the
-L<DataPort::FileType::DataDB|DataPort::FileType::DataDB> format.
-
-Use the "vmake.pl" (version make) cover script for 
-L<Test::STDmaker|Test::STDmaker> to process a SVD program
-module as follows:
-
-  vmake Docs::Site_SVD::MySVDmodule
-
-The "L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>" module
-will then provide some automation of releaseing a Perl distribution file as
+The "ExtUtils::SVDmaker" module extends
+the automation of releasing a Perl distribution file as
 follows:
 
-=over
+=over 4
 
 =item *
 
-The input data for the L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>
-is a form database file in the format of 
+The input data for the "ExtUtils::SVDmaker" module
+is a form database in the __DATA__ section of the SVD program module.
+The database is in the format of 
 L<DataPort::FileType::FormDB|DataPort::FileType::FormDB>.
-This is a efficient text database that is very close in
+This is an efficient text database that is very close in
 format to hard copy forms and may be edited by text editors
 
 =item *
 
-compares the contents of the current release with the previous
+The "ExtUtils::SVDmaker" module compares the contents of the current release with the previous
 release and automatically updates the version and date for files that
 have changed
 
 =item *
 
-generates a SVD program module from the form database data.
-
+"ExtUtils::SVDmaker" module generates a SVD program module POD from the form database data contained
+in the __DATA__ section of the SVD program module.
 
 =item *
 
-generates MANIFEST, README and Makefile.PL distribution
+"ExtUtils::SVDmaker" module generates the MANIFEST, README and Makefile.PL distribution
 files from the form database data
 
 =item *
 
-Builds the distribution *.tar.gz file
+"ExtUtils::SVDmaker" module builds the distribution *.tar.gz file using
+Perl code instead of starting tar and gzip process via a makefile build
+by MakeFile.PL. This greatly increases portability and performance.
 
 =item *
 
-Runs the installation tests on the distribution files
+Runs the installation tests on the distribution files using the
+"Test::Harness" module directly. It does not build any makefile 
+using the MakeFile.PL and starting a Test::Harness process via
+the makefile. This greatly increases portability and performance.
 
 =back
 
@@ -193,17 +196,9 @@ modules for the US DOD STD2167A bundle.
 They are broken out as separate modules because they may be
 of use outside of the US DOD STD2167A bundle.
 
-Note the 
-L<File::FileUtil|File::FileUtil>, 
-L<Test::STD::STDutil|Test::STD::STDutil> 
-L<Test::STD::Scrub|Test::STD::Scrub> 
-program modules breaks up 
-the Test::TestUtil program module
-and Test::TestUtil has disappeared.
-
 =head2 1.3 Document overview.
 
-This document releases ExtUtils::SVDmaker version 0.01
+This document releases ExtUtils::SVDmaker version 0.04
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -219,8 +214,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/ExtUtils-SVDmaker-0.01
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/ExtUtils-SVDmaker-0.01
+   http://www.softwarediamonds/packages/ExtUtils-SVDmaker-0.04
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/ExtUtils-SVDmaker-0.04
 
 
 Restrictions regarding duplication and license provisions
@@ -297,64 +292,97 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/ExtUtils_SVDmaker.pm                       0.01    2003/07/08 revised 0.01
- MANIFEST                                                     0.01    2003/07/08 generated, replaces 0.01
- Makefile.PL                                                  0.01    2003/07/08 generated, replaces 0.01
- README                                                       0.01    2003/07/08 generated, replaces 0.01
- lib/ExtUtils/SVDmaker.pm                                     1.03    2003/07/08 revised 1.02
- bin/vmake.pl                                                 1.02    2003/07/08 new
- t/ExtUtils/SVDmaker/Makefile2.PL                             0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/Makefile3.PL                             0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/MANIFEST2                                0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/README2                                  0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/README3                                  0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/SVDmaker.d                               0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/SVDmaker.pm                              0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/SVDmaker.t                               0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/SVDmaker0.pm                             0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/SVDtest.ppd                              0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/SVDtest2.pm                              0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/SVDtest2.ppd                             0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/SVDtest3.pm                              0.02    2003/07/08 new
- t/ExtUtils/SVDmaker/SVDtest3.ppd                             0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/lib/module0.pm                           0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/lib/SVDtest0.pm                          0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/lib/SVDtest1.pm                          0.02    2003/07/08 new
- t/ExtUtils/SVDmaker/t/SVDtest0.t                             0.01    2003/07/08 new
- t/ExtUtils/SVDmaker/t/SVDtest2.t                             0.06    2003/07/08 new
+ lib/Docs/Site_SVD/ExtUtils_SVDmaker.pm                       0.04    2003/08/04 revised 0.03
+ MANIFEST                                                     0.04    2003/08/04 generated, replaces 0.03
+ Makefile.PL                                                  0.04    2003/08/04 generated, replaces 0.03
+ README                                                       0.04    2003/08/04 generated, replaces 0.03
+ lib/ExtUtils/SVDmaker.pm                                     1.06    2003/08/04 revised 1.05
+ bin/vmake.pl                                                 1.04    2003/08/04 revised 1.03
+ t/ExtUtils/SVDmaker/SVDmaker.d                               0.04    2003/08/04 revised 0.03
+ t/ExtUtils/SVDmaker/SVDmaker.pm                              0.04    2003/08/04 revised 0.03
+ t/ExtUtils/SVDmaker/SVDmaker.t                               0.04    2003/08/04 revised 0.03
+ t/ExtUtils/SVDmaker/lib/SVDtest1.pm                          0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/lib/SVDtest1.t                           0.02    2003/08/04 new
+ tlib/Test/Tech.pm                                            1.12    2003/08/04 unchanged
+ tlib/File/SmartNL.pm,                                        1.12    2003/08/04 revised 1.11
+ t/ExtUtils/SVDmaker/expected/Makefile                        0.04    2003/08/04 new
+ t/ExtUtils/SVDmaker/expected/Makefile2.PL                    0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/Makefile3.PL                    0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/MANIFEST2                       0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/module0A.pm                     0.04    2003/08/04 new
+ t/ExtUtils/SVDmaker/expected/module0B.pm                     0.04    2003/08/04 new
+ t/ExtUtils/SVDmaker/expected/module2.pm                      0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/README2                         0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/README3                         0.04    2003/08/04 revised 0.03
+ t/ExtUtils/SVDmaker/expected/SVDmaker0.pm                    0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/SVDtest-0.01.html               0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/SVDtest.ppd                     0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/SVDtest0A.pm                    0.04    2003/08/04 new
+ t/ExtUtils/SVDmaker/expected/SVDtest0A.t                     0.04    2003/08/04 new
+ t/ExtUtils/SVDmaker/expected/SVDtest0B.pm                    0.04    2003/08/04 new
+ t/ExtUtils/SVDmaker/expected/SVDtest0B.t                     0.04    2003/08/04 new
+ t/ExtUtils/SVDmaker/expected/SVDtest2-0.01.html              0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/SVDtest2.pm                     0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/SVDtest2.ppd                    0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/SVDtest2.t                      0.04    2003/08/04 new
+ t/ExtUtils/SVDmaker/expected/SVDtest3-0.02.html              0.03    2003/08/04 revised 0.02
+ t/ExtUtils/SVDmaker/expected/SVDtest3.pm                     0.04    2003/08/04 revised 0.03
+ t/ExtUtils/SVDmaker/expected/SVDtest3.ppd                    0.03    2003/08/04 revised 0.02
 
 
 =head2 3.3 Changes
 
-The file names from 0.01 were changed as follows:
-
-  return if $file =~ s=lib/SVD/SVDgen.pm=lib/ExtUtils/SVDmaker.pm=;
-
 Changes are as follows:
 
 =over 4
 
-=item ExtUtils::SVDmaker 0.1
+=item ExtUtils::SVDmaker-0.01
 
 Change the name from SVD::SVDmaker to ExtUtils::SVDmaker. 
 The CPAN keepers have a no new top levels unless absolutely necessary policy.
 
 Added tests.
+
+=item ExtUtils::SVDmaker-0.02
+
+Drop tailing and starting white space for SEE_ALSO.
+Extra lines feeds was causing pod2hmtl to misbehave
+and not pick up on L< links >.
+
+Fixed error in calculation of $formDB->{PM_File_Relative} 
+
+Removed requirement for external Unix commands. 
+Added code to replace the extenal Unix commands.
+The is no longer the need for nmake, make, tar, gzip, gunzip.
+
+Change the test so that test support program modules resides in distribution
+directory tlib directory instead of the lib directory. 
+Because they are no longer in the lib directory, 
+test support files will not be installed as a pre-condition for the 
+test of this module.
+The test of this module will precede immediately.
+The test support files in the tlib directory will vanish after
+the installtion.
+
+=item ExtUtils::SVDmaker-0.03
+
+Fix some more problems due to Archive::Tar does tar correctly,
+(length of file contents does not match length in header) when
+use non Unix "\n"
+
+=item ExtUtils::SVDmaker-0.04
+
+Broke out the tar and gzip software into the modules Archive::TarGzip.
+Hopefully dealing with the Text '\n' problem by isolating and testing
+these functions separately. They also have high probability of being
+useful outside this module.
+
 =back
 
 =head2 3.4 Adaptation data.
 
 This installation requires that the installation site
 has the Perl programming language installed.
-Installation sites running Microsoft Operating systems require
-the installation of Unix utilities. 
-An excellent, highly recommended Unix utilities for Microsoft
-operating systems is unxutils by Karl M. Syring.
-A copy is available at the following web sites:
-
- http://unxutils.sourceforge.net
- http://packages.SoftwareDiamnds.com
-
 There are no other additional requirements or tailoring needed of 
 configurations files, adaptation data or other software needed for this
 installation particular to any installation site.
@@ -373,38 +401,23 @@ and installation support are as follows:
 
 =item Installation Instructions.
 
-The files may be installed under many different operating systems.
-The compresssed, archived, distribution file containing all installation
-files is at the following respository:
-
-    http://www.softwarediamonds/packages/ExtUtils-SVDmaker-0.01
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/ExtUtils-SVDmaker-0.01
-/ExtUtils-SVDmaker-0.01.tar.gz 
-
 Follow the general Perl software installation procedure
 to install the files contained in this distribution file.
 
-The distribution name for and version are as follows:
+The distribution name and version are as follows:
 
  distribution name: ExtUtils-SVDmaker
- version          : 0.01
+ version          : 0.04
 
 =item Prerequistes.
 
- 'DataPort::DataFile' => '0.02',
- 'DataPort::FileType::FormDB' => '0.02',
- 'DataPort::Maker' => '0',
- 'Test::Tech' => '1.08',
- 'Text::Scrub' => '0',
- 'IO::String' => '0',
+ 'DataPort::FileType::FormDB' => '0.03',
+ 'DataPort::Maker' => '1.04',
+ 'DataPort::DataFile' => '0.04',
  'Text::Scrub' => '0',
  'Text::Replace' => '0',
  'Text::Column' => '0',
  'File::AnySpec' => '0',
- 'File::TestPath' => '0',
- 'File::SubPM' => '0',
- 'File::PM2File' => '0',
- 'File::SmartNL' => '0',
  'File::Package' => '0',
  'File::Data' => '0',
 
@@ -636,11 +649,11 @@ __DATA__
 DISTNAME: ExtUtils-SVDmaker^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.01^
+VERSION : 0.04^
 FREEZE: 1^
-PREVIOUS_DISTNAME: SVD-SVDgen^
-PREVIOUS_RELEASE: 0.01^
-REVISION: -^
+PREVIOUS_DISTNAME:  ^
+PREVIOUS_RELEASE: 0.03^
+REVISION: C^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: 
@@ -665,11 +678,7 @@ REPOSITORY:
   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
 ^
 
-CHANGE2CURRENT: 
- return if $file =~ s=lib/SVD/SVDgen.pm=lib/ExtUtils/SVDmaker.pm=;
-
-^
-
+CHANGE2CURRENT:  ^
 RESTRUCTURE:  ^
 
 AUTO_REVISE:
@@ -678,23 +687,21 @@ bin/vmake.pl
 t/ExtUtils/SVDmaker/*
 t/ExtUtils/SVDmaker/lib/*
 t/ExtUtils/SVDmaker/t/*
+lib/Test/Tech.pm => tlib/Test/Tech.pm
+lib/File/SmartNL.pm => tlib/File/SmartNL.pm,
 ^
 
+REPLACE: t/ExtUtils/SVDmaker/expected/* ^
+
+
 PREREQ_PM:
-'DataPort::DataFile' => '0.02',
-'DataPort::FileType::FormDB' => '0.02',
-'DataPort::Maker' => '0',
-'Test::Tech' => '1.08',
-'Text::Scrub' => '0',
-'IO::String' => '0',
+'DataPort::FileType::FormDB' => '0.03',
+'DataPort::Maker' => '1.04',
+'DataPort::DataFile' => '0.04',
 'Text::Scrub' => '0',
 'Text::Replace' => '0',
 'Text::Column' => '0',
 'File::AnySpec' => '0',
-'File::TestPath' => '0',
-'File::SubPM' => '0',
-'File::PM2File' => '0',
-'File::SmartNL' => '0',
 'File::Package' => '0',
 'File::Data' => '0',
 ^
@@ -707,12 +714,47 @@ Changes are as follows:
 
 \=over 4
 
-\=item ExtUtils::SVDmaker 0.1
+\=item ExtUtils::SVDmaker-0.01
 
 Change the name from SVD::SVDmaker to ExtUtils::SVDmaker. 
 The CPAN keepers have a no new top levels unless absolutely necessary policy.
 
 Added tests.
+
+\=item ExtUtils::SVDmaker-0.02
+
+Drop tailing and starting white space for SEE_ALSO.
+Extra lines feeds was causing pod2hmtl to misbehave
+and not pick up on L< links >.
+
+Fixed error in calculation of $formDB->{PM_File_Relative} 
+
+Removed requirement for external Unix commands. 
+Added code to replace the extenal Unix commands.
+The is no longer the need for nmake, make, tar, gzip, gunzip.
+
+Change the test so that test support program modules resides in distribution
+directory tlib directory instead of the lib directory. 
+Because they are no longer in the lib directory, 
+test support files will not be installed as a pre-condition for the 
+test of this module.
+The test of this module will precede immediately.
+The test support files in the tlib directory will vanish after
+the installtion.
+
+\=item ExtUtils::SVDmaker-0.03
+
+Fix some more problems due to Archive::Tar does tar correctly,
+(length of file contents does not match length in header) when
+use non Unix "\n"
+
+\=item ExtUtils::SVDmaker-0.04
+
+Broke out the tar and gzip software into the modules Archive::TarGzip.
+Hopefully dealing with the Text '\n' problem by isolating and testing
+these functions separately. They also have high probability of being
+useful outside this module.
+
 \=back
 ^
 
@@ -722,57 +764,49 @@ As established by the L<Perl referenced documents|/2.0 SEE ALSO>,
 the "L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>" 
 program module extends the Perl language.
 
-
-The input to "L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>" is the __DATA__
-section of Software Test Description (STD)
-program module.
-The __DATA__ section must contain STD
-forms text database in the
-L<DataPort::FileType::DataDB|DataPort::FileType::DataDB> format.
-
-Use the "vmake.pl" (version make) cover script for 
-L<Test::STDmaker|Test::STDmaker> to process a SVD program
-module as follows:
-
-  vmake Docs::Site_SVD::MySVDmodule
-
-The "L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>" module
-will then provide some automation of releaseing a Perl distribution file as
+The "ExtUtils::SVDmaker" module extends
+the automation of releasing a Perl distribution file as
 follows:
 
-\=over
+\=over 4
 
 \=item *
 
-The input data for the L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>
-is a form database file in the format of 
+The input data for the "ExtUtils::SVDmaker" module
+is a form database in the __DATA__ section of the SVD program module.
+The database is in the format of 
 L<DataPort::FileType::FormDB|DataPort::FileType::FormDB>.
-This is a efficient text database that is very close in
+This is an efficient text database that is very close in
 format to hard copy forms and may be edited by text editors
 
 \=item *
 
-compares the contents of the current release with the previous
+The "ExtUtils::SVDmaker" module compares the contents of the current release with the previous
 release and automatically updates the version and date for files that
 have changed
 
 \=item *
 
-generates a SVD program module from the form database data.
-
+"ExtUtils::SVDmaker" module generates a SVD program module POD from the form database data contained
+in the __DATA__ section of the SVD program module.
 
 \=item *
 
-generates MANIFEST, README and Makefile.PL distribution
+"ExtUtils::SVDmaker" module generates the MANIFEST, README and Makefile.PL distribution
 files from the form database data
 
 \=item *
 
-Builds the distribution *.tar.gz file
+"ExtUtils::SVDmaker" module builds the distribution *.tar.gz file using
+Perl code instead of starting tar and gzip process via a makefile build
+by MakeFile.PL. This greatly increases portability and performance.
 
 \=item *
 
-Runs the installation tests on the distribution files
+Runs the installation tests on the distribution files using the
+"Test::Harness" module directly. It does not build any makefile 
+using the MakeFile.PL and starting a Test::Harness process via
+the makefile. This greatly increases portability and performance.
 
 \=back
 
@@ -780,20 +814,20 @@ The L<ExtUtils::SVDmaker|ExtUtils::SVDmaker> module is one of the
 end user, functional interface modules for the US DOD STD2167A bundle.
 Two STD2167A bundle end user modules are as follows:
 
-=over 4
+\=over 4
 
-=item L<Test::STDmaker|Test::STDmaker> module
+\=item L<Test::STDmaker|Test::STDmaker> module
 
 generates Test script, demo script and STD document POD from
 a text database in the Data::Port::FileTYpe::FormDB format.
 
-=item L<ExtUtils::SVDmaker|ExtUtils::SVDmaker> module
+\=item L<ExtUtils::SVDmaker|ExtUtils::SVDmaker> module
 
 generates SVD document POD and distribution *.tar.gz file including
 a generated Makefile.PL README and MANIFEST file from 
 a text database in the Data::Port::FileTYpe::FormDB format.
 
-=back
+\=back
 
 The dependency of the program modules in the US DOD STD2167A bundle is as follows:
 
@@ -814,17 +848,8 @@ The rest of the modules in the above dependency tree are design
 modules for the US DOD STD2167A bundle. 
 They are broken out as separate modules because they may be
 of use outside of the US DOD STD2167A bundle.
-
-Note the 
-L<File::FileUtil|File::FileUtil>, 
-L<Test::STD::STDutil|Test::STD::STDutil> 
-L<Test::STD::Scrub|Test::STD::Scrub> 
-program modules breaks up 
-the Test::TestUtil program module
-and Test::TestUtil has disappeared.
 ^
 
-
 DOCUMENT_OVERVIEW:
 This document releases ${NAME} version ${VERSION}
 providing description of the inventory, installation
@@ -886,20 +911,13 @@ ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 INSTALLATION:
-The files may be installed under many different operating systems.
-The compresssed, archived, distribution file containing all installation
-files is at the following respository:
-
- ${REPOSITORY}/${DISTNAME}-${VERSION}.tar.gz 
-
 Follow the general Perl software installation procedure
 to install the files contained in this distribution file.
 
-The distribution name for and version are as follows:
+The distribution name and version are as follows:
 
  distribution name: ${DISTNAME}
  version          : ${VERSION}
-
 ^
 
 
